SystemOrganization addCategory: #ConfigurationOfEpicea!

Object subclass: #ConfigurationOfEpicea
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfEpicea'!

!ConfigurationOfEpicea commentStamp: 'MartinDias 2/11/2014 16:29' prior: 0!
I am a Metacello configuration for Epicea.

Epicea is a tool with a model for representing code history enriched with IDE events.

Look for examples in my class-side.


Load with: 

(ConfigurationOfEpicea project version: #stable) load.!

!ConfigurationOfEpicea class methodsFor: 'development support' stamp: 'MartinDias 8/13/2013 14:02'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfEpicea class methodsFor: 'private' stamp: 'MartinDias 8/13/2013 14:02'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfEpicea class methodsFor: 'examples' stamp: 'MartinDias 10/28/2013 12:56'!
developmentWorkspace
	"To be evaluated in latest Pharo 3.0"
	
	"Start recording and open a browser"
	(#EpMonitor asClass current
		enable;
		log)
		browse.
	
	"Some examples for programatically doing some code changes"
	(#EpExamples asClass >> #createClassWithMethods) browse.
! !

!ConfigurationOfEpicea class methodsFor: 'private' stamp: 'MartinDias 8/13/2013 14:02'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfEpicea class methodsFor: 'private' stamp: 'MartinDias 8/13/2013 14:02'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfEpicea class methodsFor: 'examples' stamp: 'MartinDias 10/28/2013 12:58'!
example
	"To be evaluated in latest Pharo 3.0"
	
	"Load the project"
	self load.

	"Start recording and open a browser"
	(#EpMonitor asClass current
		enable;
		log)
		browse.
	
	"Some examples for programatically doing some code changes"
	(#EpExamples asClass >> #createClassWithMethods) browse.
! !

!ConfigurationOfEpicea class methodsFor: 'metacello tool support' stamp: 'MartinDias 8/13/2013 14:02'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfEpicea class methodsFor: 'loading' stamp: 'MartinDias 8/13/2013 14:02'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfEpicea class methodsFor: 'loading' stamp: 'MartinDias 8/13/2013 14:02'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfEpicea class methodsFor: 'loading' stamp: 'MartinDias 8/13/2013 14:02'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfEpicea class methodsFor: 'accessing' stamp: 'MartinDias 8/13/2013 14:02'!
project

	^self new project! !

!ConfigurationOfEpicea class methodsFor: 'development support' stamp: 'MartinDias 8/13/2013 14:02'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/10/2013 23:44'!
baseline10: spec
	<version: '1.0-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec
				repository: self mainRepositoryUrlString;
				package: 'Ombu' with: [ spec requires: 'Phexample' ];
				package: 'Epicea' with: [ spec requires: #(Ombu) ].
				
			self baseline10Phexample: spec.

			spec group: 'default' with: #(Epicea) ]! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/17/2013 14:43'!
baseline10Phexample: spec
	spec 
		project: 'Phexample' 
		with: [
			spec
				className: 'ConfigurationOfPhexample';
				versionString: #'bleedingEdge';
				repository: 'http://www.smalltalkhub.com/mc/Phexample/Phexample/main' ]! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/17/2013 14:42'!
baseline13: spec
	<version: '1.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.
		self baseline10Phexample: spec.
		self baseline13STON: spec.
		spec 
			package: 'Ombu' with: [
				spec requires: #('Phexample' 'STON'). ];
			package: 'Epicea' with: [
				spec requires: #(#Ombu ). ].
		spec group: 'default' with: #(#Epicea ). ].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 9/17/2013 15:05'!
baseline13STON: spec
	spec 
		project: 'STON' 
		with: [
			spec
				className: 'ConfigurationOfSton';
				versionString: #'bleedingEdge';
				repository: 'http://ss3.gemtalksystems.com/ss/STON' ].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 10/22/2013 19:44'!
baseline14: spec
	<version: '1.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.
		self baseline10Phexample: spec.
		self baseline13STON: spec.
		spec 
			package: 'Ombu' with: [
				spec requires: #('STON'). ];
			package: 'Epicea' with: [
				spec requires: #(Ombu). ].
		spec group: 'default' with: #(Epicea). ].
! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 2/10/2014 13:33'!
baseline20: spec
	<version: '2.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.
		self baseline13STON: spec.
	
		spec 
			package: 'Ombu' with: [
				spec requires: #(STON). ];
			package: 'Epicea' with: [
				spec requires: #(Ombu). ];
			package: 'EpiceaExamples' with: [
				spec requires: #(Epicea). ].
		spec group: 'default' with: #(Epicea). ].! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 3/27/2014 02:39'!
baseline33: spec
	<version: '3.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version33PostLoad.
				
		spec 
			package: 'Ombu' with: [
				spec requires: #(STON). ];
			package: 'Epicea' with: [
				spec requires: #(Ombu). ];
			package: 'EpiceaExamples' with: [
				spec requires: #(Epicea). ].

		spec group: 'default' with: #(Epicea). ].! !

!ConfigurationOfEpicea methodsFor: 'baselines' stamp: 'MartinDias 6/5/2014 17:17'!
baseline41: spec
	<version: '4.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: self mainRepositoryUrlString.

		self baseline13STON: spec.

		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version41PostLoad.
				
		spec 
			package: 'Ombu' with: [
				spec requires: #(STON). ];
			package: 'Epicea' with: [
				spec requires: #(Ombu). ];
			package: 'EpiceaExamples' with: [
				spec requires: #(Epicea). ].

		spec group: 'default' with: #(Epicea). ].! !

!ConfigurationOfEpicea methodsFor: 'accessing' stamp: 'MartinDias 8/13/2013 14:02'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfEpicea methodsFor: 'tags' stamp: 'MartinDias 6/5/2014 17:18'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '4.1-baseline'.
! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:10'!
developmentPostDoIt

	self openDevelopmentWorkspace! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/17/2014 13:13'!
hasModifiedMark: aPackageName

	^ (self mcWorkingCopyOf: aPackageName) modified! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 2/16/2014 23:27'!
isEpiceaAlreadyLoaded

	^ Smalltalk hasClassNamed: #EpMonitor! !

!ConfigurationOfEpicea methodsFor: 'accessing' stamp: 'MartinDias 8/13/2013 14:12'!
mainRepositoryUrlString
	^ 'http://smalltalkhub.com/mc/MartinDias/Epicea/main'! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/17/2014 13:13'!
mcWorkingCopyOf: aPackageName

	^ MCWorkingCopy allManagers detect: [ :each | each package name = aPackageName ]! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:10'!
openDevelopmentWorkspace

	(self class theMetaClass >> #developmentWorkspace) browse! !

!ConfigurationOfEpicea methodsFor: 'accessing' stamp: 'MartinDias 8/13/2013 14:02'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:12'!
revertAllModified: somePackageNames

	somePackageNames 
		do: [ :name |
			(self hasModifiedMark: name)
				ifTrue: [ 
					Gofer new
						url: 'http://smalltalkhub.com/mc/Pharo/Pharo30/main';
						package: name;
						revert ] ]! !

!ConfigurationOfEpicea methodsFor: 'tags' stamp: 'MartinDias 7/17/2014 15:28'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '4.1'.
! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 2/16/2014 23:35'!
stopLogging
	"Stop and reset recording IDE events"

	(Smalltalk classNamed: #EpMonitor) reset! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 7/17/2014 13:43'!
unmarkAsModified: somePackageNames
	"HACK: Unmark as modified the foreign packages where Epicea overrides methods. Not needed anymoew: I discovered that the same effect can be obtained just suffixing the protocols with -override."

	somePackageNames do: [ :name |
		(self mcWorkingCopyOf: name) modified: false ]! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/10/2013 23:18'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec 
			description: 'First public version, migrated from sandbox repository.';
			author: 'Martin Dias';
			timestamp: '2013-08-13'.
		
		spec
			package: 'Epicea'  with: 'Epicea-MartinDias.94';
			package: 'Ombu' with: 'Ombu-MartinDias.12';			
			project: 'Phexample' with: #development ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/10/2013 23:18'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec 
			description: 'Visualise comment in nice morphs. Text search is broken. Added some tests.';
			author: 'Martin Dias';
			timestamp: '2013-08-14'.
		
		spec
			package: 'Epicea'  with: 'Epicea-MartinDias.115';
			package: 'Ombu' with: 'Ombu-MartinDias.12';			
			project: 'Phexample' with: #development ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/17/2013 14:45'!
version12: spec
	<version: '1.2' imports: #('1.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Version showed at ESUG Innovation Technology Awards. Image used: Pharo-30381.'.
		spec author: 'MartinDias'.
		spec timestamp: '9/10/2013 09:57'.
		spec project: 'Phexample' with: '1.2'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.96';
			package: 'Epicea' with: 'Epicea-MartinDias.229'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 9/25/2013 14:09'!
version13: spec
	<version: '1.3' imports: #('1.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Support STON persistence and other improvements.'.
		spec author: 'MartinDias'.
		spec timestamp: '25/09/2013'.
		spec project: 'Phexample' with: '1.2'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.106';
			package: 'Epicea' with: 'Epicea-MartinDias.256'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 10/23/2013 17:49'!
version14: spec
	<version: '1.4' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'A lot of visual improvements and multiple fixes.'.
		spec author: 'MartinDias'.
		spec timestamp: '22/10/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.110';
			package: 'Epicea' with: 'Epicea-MartinDias.329'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 10/24/2013 13:09'!
version15: spec
	<version: '1.5' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Just fixed Undo and Redo operations of previous version.'.
		spec author: 'MartinDias'.
		spec timestamp: '24/10/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.110';
			package: 'Epicea' with: 'Epicea-MartinDias.330'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 10/25/2013 16:02'!
version16: spec
	<version: '1.6' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Added icons to contextual menu.
			- Some internal refactorings.
			- Some minor fixes.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '25/10/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.110';
			package: 'Epicea' with: 'Epicea-MartinDias.338'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 11/13/2013 18:30'!
version17: spec
	<version: '1.7' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- ChangeSet importer.
			- Working in Pharo #30570.
				- Migrated to new Spec.
				- Some extensions were integrated.
			- More tests.
			- General clean up.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '13/11/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.120';
			package: 'Epicea' with: 'Epicea-MartinDias.417'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 11/14/2013 16:54'!
version18: spec
	<version: '1.8' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Created File Reader Service for ChangeSet importer.
			- Working in Pharo #30572.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '14/11/2013'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.120';
			package: 'Epicea' with: 'Epicea-MartinDias.425'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 1/14/2014 17:39'!
version19: spec
	<version: '1.9' imports: #('1.4-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Some fixes
			- Working in Pharo #30695.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '14/01/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.124';
			package: 'Epicea' with: 'Epicea-MartinDias.469'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/11/2014 16:25'!
version20: spec
	<version: '2.0' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Ready for preliminar study.
			- New: Sessions Browser.
			- Working in Pharo #30753.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '10/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.483'.
			
		spec
			preLoadDoIt: #version20PreLoad;
			postLoadDoIt: #version20PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:13'!
version20PostLoad

	self unmarkAsModified: {'Tools'. 'Monticello'. 'MonticelloGUI'. 'NautilusRefactoring'. 'OpalCompiler-Core'}.
	self version20StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 2/16/2014 23:27'!
version20PreLoad

	self isEpiceaAlreadyLoaded ifTrue: [
		self stopLogging ]! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 4/14/2014 17:07'!
version20StartLogging
	"Start recording IDE events"

	#EpSessionStoreStrategy asClass 
		defaultBaseDirectoryLocator: FileLocator preferences / 'pharo' / 'epicea-study-1'.
	
	#EpMonitor asClass current enable.! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/11/2014 16:25'!
version21: spec
	<version: '2.1' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Like 2.0 but working better with Komitter.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '11/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.485'.
			
		spec
			preLoadDoIt: #version20PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:13'!
version21PostLoad

	self unmarkAsModified: {'Tools'. 'Monticello'. 'NautilusRefactoring'. 'OpalCompiler-Core'}.
	self version20StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/11/2014 20:39'!
version22: spec
	<version: '2.2' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Fixed bugs with refactorings.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '11/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.488'.
			
		spec
			preLoadDoIt: #version20PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/12/2014 14:18'!
version23: spec
	<version: '2.3' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Same code as 2.2, but safer for upgrading from previous versions.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '12/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.488'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:05'!
version23OverridenPackageNames

	^ {'Tools'. 'Monticello'. 'MonticelloGUI'. 'NautilusRefactoring'. 'OpalCompiler-Core'}! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:07'!
version23PreLoad

	self isEpiceaAlreadyLoaded ifTrue: [
		self stopLogging.
		self revertAllModified: self version23OverridenPackageNames ]! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/13/2014 16:51'!
version24: spec
	<version: '2.4' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Log test suite runs.
			- Fix bug when Author is not set.
			- Fix/workaround for bug in class modification.
			- Added a new view for EpLogBrowser.
			- Show ombu filename in EpLogBrowser.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '13/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.125';
			package: 'Epicea' with: 'Epicea-MartinDias.494'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/14/2014 11:12'!
version25: spec
	<version: '2.5' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Ombu: Fix bug while parsing files.
			- Ombu: Tolerate Ston parsing errors.
			- Some visual changes on Log Browser and Session Browser.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '14/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.127';
			package: 'Epicea' with: 'Epicea-MartinDias.504'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/14/2014 13:48'!
version26: spec
	<version: '2.6' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Ombu: Fix Ston materialization of RPackageTags.
			- Epicea: Added a button to absent entry, enabling navigation between ombu files.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '14/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.505'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/19/2014 13:47'!
version27: spec
	<version: '2.7' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Fix: EpMethodRemoval was not holding the real protocol.
			- Feature: Enable multiple selection in items list.
			- Clean up: removed unused code
			- Fix: undo and redo for multiple selection
			'.
		spec author: 'MartinDias'.
		spec timestamp: '19/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.511'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/19/2014 14:45'!
version28: spec
	<version: '2.8' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Minor visual improvements in Browser:
			- remember how many pages where fetched.
			- set a title to the items menu
			'.
		spec author: 'MartinDias'.
		spec timestamp: '19/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.513'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/19/2014 18:15'!
version29: spec
	<version: '2.9' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			Fixed 2 failing tests. Now everything is green :)
			'.
		spec author: 'MartinDias'.
		spec timestamp: '19/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.514'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 2/21/2014 16:18'!
version30: spec
	<version: '3.0' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Update for Pharo 30777.
			- Increased browser initial #pageSize from 20 to 30.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '21/02/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.128';
			package: 'Epicea' with: 'Epicea-MartinDias.516'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 3/3/2014 18:30'!
version31: spec
	<version: '3.1' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Added "any code change" filter.
			- Now only EpEntryItems in the selection are taken into account for menu actions.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '03/03/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.129';
			package: 'Epicea' with: 'Epicea-MartinDias.529'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 3/4/2014 18:49'!
version32: spec
	<version: '3.2' imports: #('2.0-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
			- Order the entries for redo and undo operations using the timestamp. 
				(Much better than using the user selection order).
			- Implemented #asEpiceaRingDefinition in metamodel and ring definitions. 
				The advantages are: 
				- Store package name always, instead of either nil or the RPackage.
				- Huge speed up in ChangeSet importation since it was storing parent of the methods.
				- It is possible to Redo or Undo an event imported from a ChangeSet (it was almost impossible).
				- Also do not store #passive annotation on each method, which saves a bit of space.
			'.
		spec author: 'MartinDias'.
		spec timestamp: '04/03/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.129';
			package: 'Epicea' with: 'Epicea-MartinDias.531'.
			
		spec
			preLoadDoIt: #version23PreLoad;
			postLoadDoIt: #version21PostLoad ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/15/2014 17:40'!
version33: spec
	<version: '3.3' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '15/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.149';
			package: 'Epicea' with: 'Epicea-MartinDias.576'. ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:06'!
version33OverridenPackageNames

	^ {'Tools'. 'Monticello'. 'NautilusRefactoring'. 'OpalCompiler-Core'. 'SUnit-Core'}! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:13'!
version33PostLoad

	self unmarkAsModified: self version33OverridenPackageNames.
	self version33StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 3/27/2014 12:07'!
version33PreLoad

	self isEpiceaAlreadyLoaded ifTrue: [
		self stopLogging.
		self revertAllModified: self version33OverridenPackageNames ]! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 4/14/2014 17:06'!
version33StartLogging
	"Start recording IDE events"

	#OmSessionStore asClass 
		defaultBaseDirectoryLocator: FileLocator preferences / 'pharo' / 'epicea-3.3'.
	
	#EpMonitor asClass current enable.! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/16/2014 18:12'!
version34: spec
	<version: '3.4' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '16/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.153';
			package: 'Epicea' with: 'Epicea-MartinDias.578'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/17/2014 14:43'!
version35: spec
	<version: '3.5' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '17/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.154';
			package: 'Epicea' with: 'Epicea-MartinDias.580'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/17/2014 17:02'!
version36: spec
	<version: '3.6' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '17/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.154';
			package: 'Epicea' with: 'Epicea-MartinDias.582'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 4/23/2014 13:25'!
version37: spec
	<version: '3.7' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'MartinDias'.
		spec timestamp: '23/04/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.154';
			package: 'Epicea' with: 'Epicea-MartinDias.583'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 5/3/2014 21:15'!
version38: spec
	<version: '3.8' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Added a group for World Menu'.
		spec author: 'MartinDias'.
		spec timestamp: '03/05/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.154';
			package: 'Epicea' with: 'Epicea-MartinDias.585'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 5/27/2014 15:45'!
version39: spec
	<version: '3.9' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* New feature: File Out to Ombu
	* New feature: File Out to ChangeSet
	* Bug fix: Issues when importing ChangeSet
	* New feature: Test that overriding external methods in system are right
	* Bug fix: It was loosing class-side definition modifications.
	* Clean up: Removed tons of unused classes and methods.
	* New feature: Show class-side definitions in content tab.
	* Others
		'.
		spec author: 'MartinDias'.
		spec timestamp: '27/05/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.155';
			package: 'Epicea' with: 'Epicea-MartinDias.610'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 6/5/2014 14:49'!
version40: spec
	<version: '4.0' imports: #('3.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* Session browser: sort by clicking on columns
	* OmFileStores are lazy.
'.
		spec author: 'MartinDias'.
		spec timestamp: '05/06/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.161';
			package: 'Epicea' with: 'Epicea-MartinDias.617'. ].! !

!ConfigurationOfEpicea methodsFor: 'versions' stamp: 'MartinDias 7/17/2014 15:28'!
version41: spec
	<version: '4.1' imports: #('4.1-baseline') >

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '
	* The base for files is a FileLocator instead of a FileReference. This way it should tolerate sending an image from one computer to another with epicea already enabled inside.
	* Support for multiple themes, e.g. the DarkTheme.
'.
		spec author: 'MartinDias'.
		spec timestamp: '17/07/2014'.
		spec 
			package: 'Ombu' with: 'Ombu-MartinDias.162';
			package: 'Epicea' with: 'Epicea-MartinDias.620'. ].! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 6/5/2014 17:17'!
version41PostLoad

	self unmarkAsModified: self version33OverridenPackageNames.
	self version41StartLogging.! !

!ConfigurationOfEpicea methodsFor: 'scripting' stamp: 'MartinDias 6/5/2014 17:16'!
version41StartLogging
	"Start recording IDE events"

	#OmSessionStore asClass 
		defaultBaseLocator: FileLocator preferences / 'pharo' / 'epicea-3.3'.
	
	#EpMonitor asClass current enable.! !
